<?php

// ---------------------------------------------------------------
//
// ---------------------------------------------------
// copyright 2000 by voxeo corporation. (see LGPL.txt)
// ---------------------------------------------------
//
// v1.0 Coded in PHP 4.0
// v1.0 Coded by Stephen J. Lewis
//
// This application dynamically generates CallXML code from a
// database file.  The DB file depends on the operating system.
//
//      Database-Linux.inc          <---- This contains all the abstracted database
//                                        routines for linux.
//      Database-Win32.inc          <---- This contains all the abstracted database
//                                        routines for Win32.
//
//
// It is also associated with the CallXML files:
// 		CallDestination.xml
//		DoTheCall.xml
//
//		Three other files are used to edit the AutoAttendent:
//		---------------------------------------------------
//		AutoAttendantAdmin.php
//		AutoAttendantWorkhorse.php
//      passwords.inc
//
//   These handle the actual Destination calling that is 
//   generated from the code below here.  They are hardcoded
//   and simply use the variables passed in from the database.
// 
// The database is either an Interbase resource or MS Access file
// and contains one table, named AutoAttendantDB, with columns called:
//  	'Digit,'      'AudioURL,'     'Destination,' 'MenuName,' 
// 		'ActionType,' 'MenuPosition,' and 'UniqueID.'
//
// The Digit column should always be 1-9, 0, *, #, A, B, C, and D.
// These are the valid digits that CallXML recognizes
// in terms of possible keypresses.
// ---------------------------------------------------------------


//-----------------------------------------------------
// This little tweak is in case we are running under an
// Operating System that use case-sensitive URLs.
//-----------------------------------------------------

if ($HTTP_GET_VARS["os"] != "") { $HTTP_GET_VARS["OS"] = $HTTP_GET_VARS["os"]; }

$HTTP_GET_VARS["OS"] = strtolower($HTTP_GET_VARS["OS"]);

if ($HTTP_GET_VARS["OS"] == "linux") { include('database-linux.inc'); }
else 						         { include('database-win32.inc'); }

include('passwords.inc');

// -------------------------------
// Begin main portion for the code
// -------------------------------

function BuildCallXMLScript() { 
  global $HTTP_GET_VARS; 

  //------------------------------------------------------
  // Make sure we are pointing to the right database file,
  // depending on the operating system.  These can be 
  // changed depending on the developer's setup and paths.
  //------------------------------------------------------
  
  if ($HTTP_GET_VARS["OS"] == "linux") { 
    $DatabaseName = "/www/html/aa/aa.gdb";
	$Path         = "http://linux1.voxeo.com/aa/";
  }  // if statement
  else { 
    $DatabaseName = "AutoAttendantDB";
    $Path         = "http://appserverdev.voxeo.com/autoattendant/";
  }  // else statement 
    
  $NumberOfMenuRepetitions = 3;
  $DefaultMenuName         = "MainMenu";
  
  $TempConnection = OpenDatabase($DatabaseName); 
  
  //--------------------------------------------------------
  // We grab the MenuName from the URL QueryString.  It
  // defaults to "MainMenu" so it is important to ensure
  // that the database record itself reflects this.  
  // Otherwise, AutoAttendant will be looking for "MainMenu"
  // by default, and if the database does not match, then
  // no CallXML menus will be generated.
  //--------------------------------------------------------
  
  if ($HTTP_GET_VARS["menuname"] != "") { 
    $HTTP_GET_VARS["MenuName"] = $HTTP_GET_VARS["menuname"];
  }  // if statement
  
  $ActiveMenu = $HTTP_GET_VARS["MenuName"];
  
  If ($ActiveMenu == "") {
    $ActiveMenu = $DefaultMenuName;
  } // if statement

  //-----------------------
  // Build the query string
  //-----------------------
  
  $TempSQL = "select * from AUTOATTENDANTDB where MENUNAME ='$ActiveMenu' order by MENUPOSITION";
  
  //-------------------------------
  // Query database for information
  //-------------------------------
  
  $TempDataBase = ReadDatabase( $TempConnection, $TempSQL ); 

  //-----------------------------------
  // Begin building the CallXML script
  //-----------------------------------
  
  echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
  echo "<callxml>\n";
  echo "<answer/>\n";
  
  echo "<assign var=\"OS\"   value=\"" . $HTTP_GET_VARS["OS"] . "\"/>";
  echo "<assign var=\"Path\" value=\"" . $Path . "\"/>";
  
  $TermDigitsStr         = "";
  $ActualDigitStr        = "";
  $FileNames	         = Array();
  $Destinations          = Array();
  $GreetingFiles         = Array();
  $ActionTypes           = Array();
  $NumberOfDestinations  = 0;
  $NumberOfFilenames     = 0;
  $NumberOfGreetingFiles = 0;
  $NumberOfActionTypes   = 0;
  
  //-------------------------
  // Parse the database query 
  //-------------------------
  
  while( $TempRow = FetchRowFromDatabase( $TempDataBase ) ) { 
    $Digit       = GetResultFromRow( "DIGIT",       $TempRow, $TempDatabase );
    $AudioURL    = GetResultFromRow( "AUDIOURL",    $TempRow, $TempDatabase ); 
    $Destination = GetResultFromRow( "DESTINATION", $TempRow, $TempDatabase );
    $ActionType  = GetResultFromRow( "ACTIONTYPE",  $TempRow, $TempDatabase );
		
	//--------------------------------------------------------
	// If there is an actual file and Destination in this record
	// then add the digit to the string of termdigits 
	//--------------------------------------------------------
	
	if ($ActionType == "Greeting") {
	  $NumberOfGreetingFiles++;
	  $NumberOfActionTypes++;
	  $GreetingFiles[$NumberOfGreetingFiles] = $AudioURL;
	  $TermDigitsStr 						 = $TermDigitsStr . $Digit;	  
	}  // if statement
	elseif ($AudioURL != "") {
	  //--------------------------------------------
	  // TermDigitStr keeps track of all the digits,
	  // but ActualDigitStr keeps track of only the
	  // non-greetingfile digits.
	  //--------------------------------------------
	
	  $TermDigitsStr  = $TermDigitsStr  . $Digit;
	  $ActualDigitStr = $ActualDigitStr . $Digit;
	  
	  //----------------------------------------------------
	  // Build up some holding variables so we do not
	  // have to parse the database query a second time.
	  //----------------------------------------------------
		
	  $NumberOfFilenames++;
	  $NumberOfDestinations++;
	  $NumberOfActionTypes++;		
	  
	  $FileNames[$NumberOfFilenames]       = $AudioURL;
	  $Destinations[$NumberOfDestinations] = $Destination;
	  $ActionTypes[$NumberOfActionTypes]   = $ActionType;
	}  // elseif statement
  }  // while statement
 
  // ---------------------------
  // Script the greeting file(s)
  // ---------------------------
  
  for ($Loopy = 1; $Loopy <= $NumberOfGreetingFiles; $Loopy++) {
    echo "<block label=\"GreetingMenu\" " .
         "repeat=\"1\" " .
         "cleardigits=\"TRUE\">\n";
    echo "<playaudio value=\"" . $GreetingFiles[$Loopy] . "\" " .
  	     "termdigits=\"\" " .
	     "cleardigits=\"FALSE\"/>\n";	  
    echo "</block>";
  }  // for statement
  
  echo "<block label=\"AutoAttendentMenu\" " .
       "repeat=\"" . $NumberOfMenuRepetitions . "\" " .
       "cleardigits=\"TRUE\">\n";
    
  //----------------------------------------------
  // Parse the holding variables because
  // we needed the entire $TermdigitStr before
  // we could properly build the PlayAudio 
  // and event handler scripts.
  //
  // 
  // First we do the PlayAudio scripts.  Also, if
  // all the audio files are going to be in a specific
  // directory, you use the Path variable assigned
  // above, preventing the need for fully qualified
  // URLs in the AudioURL database.
  // ---------------------------------------------
  
  for ($Loopy = 1; $Loopy <= $NumberOfFilenames; $Loopy++) {
    echo "<text termdigits=\"" . $ActualDigitStr . "\">";
	echo "Too reeech";
	echo "</text>";
	
    echo "<playaudio value=\"" . $FileNames[$Loopy] . "\" " .
  		 "termdigits=\"" . $ActualDigitStr . "\" " .
		 "cleardigits=\"FALSE\"/>\n";	
		 
    echo "<text termdigits=\"" . $ActualDigitStr . "\">";
	echo "pleeece press " . $ActualDigitStr[$Loopy - 1];
	echo "</text>";		   
  }  // For Statement  
  
  // ---------------------------------------------------------------
  // Next we do the Event handlers.  The Offset variable is because
  // we typically have at least one greeting file, so we need to 
  // keep track of our arrays as they are often 1 or 2 indices apart.
  // ---------------------------------------------------------------
  
  $Offset = 0;
  
  for ($Loopy = 1; $Loopy <= $NumberOfActionTypes; $Loopy++) {	   
	if ($ActionTypes[$Loopy] == "Call") {
  	  echo "<ontermdigit value=\"" . $TermDigitsStr[$Loopy - 1] . "\">\n";
	  echo "<assign var=\"NumToCall\" value=\"" . $Destinations[$Loopy - $Offset] . "\"/>";
	  echo "<goto value=\"$Path" . "calldestination.xml\" submit=\"*\" " .
		   "method=\"get\"/>\n";
	  echo "</ontermdigit>\n";		
	}  // if statement  
	elseif ($ActionTypes[$Loopy] == "Menu") {
  	  echo "<ontermdigit value=\"" . $TermDigitsStr[$Loopy - 1] . "\">\n";
	  echo "<assign var=\"MenuName\" value=\"" . $Destinations[$Loopy - $Offset] . "\"/>";
	  echo "<goto value=\"$Path" . "autoattendant.php\" submit=\"*\" " .
		   "method=\"get\"/>\n";
	  echo "</ontermdigit>\n";		
	}  // elseif statement
	elseif ($ActionTypes[$Loopy] == "Hangup") {
  	  echo "<ontermdigit value=\"" . $TermDigitsStr[$Loopy - 1] . "\">\n";
	  echo "<hangup/>";
	  echo "</ontermdigit>\n";		
	}  // elseif statement
	elseif ($ActionTypes[$Loopy] == "URL") {
  	  echo "<ontermdigit value=\"" . $TermDigitsStr[$Loopy - 1] . "\">\n";
	  echo "<goto value=\"" . $Destinations[$Loopy - $Offset] . "\" " .
	       "submit=\"*\" method=\"get\"/>\n";
	  echo "</ontermdigit>\n";		
	}  // elseif statement
	else {
	  $Offset++;
	}  // else statement
  }  // For statement
  
  //----------------------
  //Finish up the CallXML
  //----------------------
  
  echo "</block>\n";
  
  echo "<hangup/>\n".
  	   "</callxml>";
  
  //------------------------------
  // Close the Database connection
  //------------------------------
  
  CloseDatabase( $TempConnection ); 
  
  exit();
} 

BuildCallXMLScript();

?>

